unit MainForm;

{
2000 Apr 11  1.0.0  Simple sinewave generator
2000 Aug 11  1.1.0  Derived toneburst generator
                    Make generator a separate unit, Beeper
2001 Jul 16  1.2.0  Version for Delphi 5
2002 Dec 07  1.4.0  Add Risetime/Falltime, and Amplitude properties
                    Now needs Math unit


Copyright  David J Taylor, Edinburgh
Web site:  www.satsignal.net
E-mail:    davidtaylor@writeme.com
}

interface

uses
  SysUtils, Controls, Forms, Beeper, Classes, StdCtrls, ComCtrls;


type
  TFormMain = class(TForm)
    ScrollBarFrequency: TScrollBar;
    Label1: TLabel;
    LabelFreq: TLabel;
    ButtonClose: TButton;
    ScrollBarDuration: TScrollBar;
    Label2: TLabel;
    LabelDuration: TLabel;
    ButtonGo: TButton;
    CheckBoxDeclick: TCheckBox;
    UpDownAmplitude: TUpDown;
    EditdB: TEdit;
    LabeldB: TLabel;
    LabelAmplitude: TLabel;
    procedure ButtonGoClick (Sender: TObject);
    procedure ButtonCloseClick (Sender: TObject);
    procedure FormCloseQuery (Sender: TObject; var CanClose: Boolean);
    procedure FormCreate (Sender: TObject);
    procedure FormShow (Sender: TObject);
    procedure ScrollBarDurationChange (Sender: TObject);
    procedure ScrollBarFrequencyChange (Sender: TObject);
    procedure UpDownAmplitudeClick (Sender: TObject; Button: TUDBtnType);
  private
    { Private declarations }
    toneburst: TToneBurst;
    duration: integer;
    frequency: integer;
  public
    { Public declarations }
  end;

var
  FormMain: TFormMain;


implementation

uses
  Math;

{$R *.DFM}

procedure TFormMain.ButtonCloseClick (Sender: TObject);
begin
  Close;
end;

procedure TFormMain.ButtonGoClick (Sender: TObject);
begin
  toneburst.Frequency := frequency;
  toneburst.Duration := duration;
  if CheckBoxDeclick.Checked
  then
    begin
    toneburst.Risetime := 10;  // in milliseconds
    toneburst.Falltime := 10;
    end
  else
    begin
    toneburst.Risetime := 0;
    toneburst.Falltime := 0;
    end;
  toneburst.Sound;
end;

procedure TFormMain.FormCloseQuery (Sender: TObject;  var CanClose: Boolean);
begin
  toneburst.Shutdown;
end;

procedure TFormMain.FormCreate (Sender: TObject);
begin
  DesktopFont := True;
  toneburst := TToneburst.Create (Self);
  toneburst.Parent := Self;
end;

procedure TFormMain.FormShow (Sender: TObject);
begin
  ScrollBarFrequency.OnChange (Self);
  ScrollBarDuration.OnChange (Self);
  UpDownAmplitude.OnClick (Self, btNext);
end;

procedure TFormMain.ScrollBarDurationChange (Sender: TObject);
begin
  duration := ScrollBarDuration.Position;
  LabelDuration.Caption := IntToStr (duration) + ' ms';
end;

procedure TFormMain.ScrollBarFrequencyChange (Sender: TObject);
begin
  frequency := ScrollBarFrequency.Position;
  LabelFreq.Caption := IntToStr (frequency) + ' Hz';
end;

procedure TFormMain.UpDownAmplitudeClick (Sender: TObject;  Button: TUDBtnType);
var
  amplitude: single;
begin
  amplitude := Power (10, UpDownAmplitude.Position / 20);
  toneburst.Amplitude := amplitude;
end;

end.

